@@ -1,11 +1,11 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004 Free Software Foundation, Inc.
+   Copyright (C) 2000,2001,2002,2003,2004,2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -44,10 +44,10 @@ SCM_DEFINE(rad_dict_name_to_attr, "rad-dict-name->attr", 1, 0, 0,
         grad_dict_attr_t *attr;
         int vendor;
         
-        if (SCM_IMP(NAME) && SCM_INUMP(NAME)) {
-                attr = grad_attr_number_to_dict(SCM_INUM(NAME));
-        } else if (SCM_NIMP(NAME) && SCM_STRINGP(NAME)) {
-                attr = grad_attr_name_to_dict(SCM_STRING_CHARS(NAME));
+        if (scm_is_integer(NAME)) {
+                attr = grad_attr_number_to_dict(scm_to_int(NAME));
+        } else if (scm_is_string(NAME)) {
+                attr = grad_attr_name_to_dict(scm_i_string_chars(NAME));
         } else {
                 SCM_ASSERT(0, NAME, SCM_ARG1, FUNC_NAME);
         }
@@ -57,12 +57,12 @@ SCM_DEFINE(rad_dict_name_to_attr, "rad-dict-name->attr", 1, 0, 0,
 
         vendor = GRAD_VENDOR_CODE(attr->value);
         return scm_list_4(scm_makfrom0str(attr->name),
-                         SCM_MAKINUM(vendor ?
-                                     attr->value - (vendor << 16) :
-                                     attr->value),
-                         SCM_MAKINUM(attr->type),
+                          scm_from_int(vendor ?
+                                       attr->value - (vendor << 16) :
+                                       attr->value),
+                         scm_from_int(attr->type),
                          vendor ?
-                         SCM_MAKINUM(grad_vendor_id_to_pec(vendor)) :
+                         scm_from_int(grad_vendor_id_to_pec(vendor)) :
                          SCM_BOOL_F);
 }
 #undef FUNC_NAME
@@ -76,10 +76,10 @@ SCM_DEFINE(rad_dict_value_to_name, "rad-dict-value->name", 2, 0, 0,
         grad_dict_attr_t *attr;
         grad_dict_value_t *val;
 
-        if (SCM_IMP(ATTR) && SCM_INUMP(ATTR)) {
-                attr = grad_attr_number_to_dict(SCM_INUM(ATTR));
-        } else if (SCM_NIMP(ATTR) && SCM_STRINGP(ATTR)) {
-                attr = grad_attr_name_to_dict(SCM_STRING_CHARS(ATTR));
+        if (scm_is_integer(ATTR)) {
+                attr = grad_attr_number_to_dict(scm_to_int(ATTR));
+        } else if (scm_is_string(ATTR)) {
+                attr = grad_attr_name_to_dict(scm_i_string_chars(ATTR));
         }
 
         if (!attr) {
@@ -88,9 +88,8 @@ SCM_DEFINE(rad_dict_value_to_name, "rad-dict-value->name", 2, 0, 0,
                                scm_list_1(ATTR));
         }
 
-        SCM_ASSERT((SCM_IMP(VALUE) && SCM_INUMP(VALUE)),
-                   VALUE, SCM_ARG1, FUNC_NAME);
-        val = grad_value_lookup(SCM_INUM(VALUE), attr->name);
+        SCM_ASSERT(scm_is_integer(VALUE), VALUE, SCM_ARG1, FUNC_NAME);
+        val = grad_value_lookup(scm_to_int(VALUE), attr->name);
 	if (!val)
 		scm_misc_error(FUNC_NAME,
                                "Value ~S not defined for attribute ~S",
@@ -107,24 +106,23 @@ SCM_DEFINE(rad_dict_name_to_value, "rad-dict-name->value", 2, 0, 0,
         grad_dict_attr_t *attr;
         grad_dict_value_t *val;
         
-        if (SCM_IMP(ATTR) && SCM_INUMP(ATTR)) {
-                attr = grad_attr_number_to_dict(SCM_INUM(ATTR));
-        } else if (SCM_NIMP(ATTR) && SCM_STRINGP(ATTR)) {
-                attr = grad_attr_name_to_dict(SCM_STRING_CHARS(ATTR));
+        if (scm_is_integer(ATTR)) {
+                attr = grad_attr_number_to_dict(scm_to_int(ATTR));
+        } else if (scm_is_string(ATTR)) {
+                attr = grad_attr_name_to_dict(scm_i_string_chars(ATTR));
         }
         if (!attr) {
                 scm_misc_error(FUNC_NAME,
                                "Unknown attribute: ~S",
                                scm_list_1(ATTR));
         }
-	SCM_ASSERT (SCM_NIMP(VALUE) && SCM_STRINGP(VALUE),
-		    VALUE, SCM_ARG2, FUNC_NAME);
+	SCM_ASSERT(scm_is_string(VALUE), VALUE, SCM_ARG2, FUNC_NAME);
         
         /*FIXME:
-          val = grad_value_name_to_value_strict(attr->value, SCM_STRING_CHARS(VALUE));
+          val = grad_value_name_to_value_strict(attr->value, scm_i_string_chars(VALUE));
           */
-        val = grad_value_name_to_value(SCM_STRING_CHARS(VALUE), attr->value);
-        return val ? scm_long2num(val->value) : SCM_BOOL_F;
+        val = grad_value_name_to_value(scm_i_string_chars(VALUE), attr->value);
+        return val ? scm_from_long(val->value) : SCM_BOOL_F;
 }
 #undef FUNC_NAME
 
@@ -135,8 +133,8 @@ SCM_DEFINE(rad_dict_pec_to_vendor, "rad-dict-pec->vendor", 1, 0, 0,
 {
         char *s;
         
-        SCM_ASSERT(SCM_IMP(PEC) && SCM_INUMP(PEC), PEC, SCM_ARG1, FUNC_NAME);
-        s = grad_vendor_pec_to_name(SCM_INUM(PEC));
+        SCM_ASSERT(scm_is_integer(PEC), PEC, SCM_ARG1, FUNC_NAME);
+        s = grad_vendor_pec_to_name(scm_to_int(PEC));
         return s ? scm_makfrom0str(s) : SCM_BOOL_F;
 }
 #undef FUNC_NAME
